from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor
REQUIRED_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
required_permissions: _descriptor.FieldDescriptor
REQUIRED_ROLES_FIELD_NUMBER: _ClassVar[int]
required_roles: _descriptor.FieldDescriptor
STANDARD_ROLES_FIELD_NUMBER: _ClassVar[int]
standard_roles: _descriptor.FieldDescriptor

class StandardRole(_message.Message):
    __slots__ = ("name", "permissions")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    permissions: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., permissions: _Optional[_Iterable[str]] = ...) -> None: ...

class PermissionStringList(_message.Message):
    __slots__ = ("permissions",)
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    permissions: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, permissions: _Optional[_Iterable[str]] = ...) -> None: ...

class StandardRoleNameList(_message.Message):
    __slots__ = ("roles",)
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, roles: _Optional[_Iterable[str]] = ...) -> None: ...

class StandardRoleList(_message.Message):
    __slots__ = ("roles",)
    ROLES_FIELD_NUMBER: _ClassVar[int]
    roles: _containers.RepeatedCompositeFieldContainer[StandardRole]
    def __init__(self, roles: _Optional[_Iterable[_Union[StandardRole, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Permission(_message.Message):
    __slots__ = ("service_provider", "service", "description")
    SERVICE_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    service_provider: str
    service: str
    description: str
    def __init__(self, service_provider: _Optional[str] = ..., service: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...



from meshtrade.trading.limit_order.v1 import limit_order_pb2 as _limit_order_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetLimitOrderRequest(_message.Message):
    __slots__ = ("number",)
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    number: str
    def __init__(self, number: _Optional[str] = ...) -> None: ...

class GetLimitOrderResponse(_message.Message):
    __slots__ = ("limitorder",)
    LIMITORDER_FIELD_NUMBER: _ClassVar[int]
    limitorder: _limit_order_pb2.LimitOrder
    def __init__(self, limitorder: _Optional[_Union[_limit_order_pb2.LimitOrder, _Mapping]] = ...) -> None: ...



from meshtrade.iam.group.v1 import group_pb2 as _group_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetGroupRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetGroupResponse(_message.Message):
    __slots__ = ("group",)
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/wallet/account/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/wallet/account/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from meshtrade.option.v1 import auth_pb2 as meshtrade_dot_option_dot_v1_dot_auth__pb2
from meshtrade.option.v1 import service_type_pb2 as meshtrade_dot_option_dot_v1_dot_service__type__pb2
from meshtrade.type.v1 import ledger_pb2 as meshtrade_dot_type_dot_v1_dot_ledger__pb2
from meshtrade.wallet.account.v1 import account_pb2 as meshtrade_dot_wallet_dot_account_dot_v1_dot_account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)meshtrade/wallet/account/v1/service.proto\x12\x1bmeshtrade.wallet.account.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1emeshtrade/option/v1/auth.proto\x1a&meshtrade/option/v1/service_type.proto\x1a\x1emeshtrade/type/v1/ledger.proto\x1a)meshtrade/wallet/account/v1/account.proto\"\x8b\x01\n\x14\x43reateAccountRequest\x12\"\n\x05label\x18\x01 \x01(\tB\x0c\xbaH\tr\x04\x10\x03\x18\x32\xc8\x01\x01R\x05label\x12;\n\x06ledger\x18\x02 \x01(\x0e\x32\x19.meshtrade.type.v1.LedgerB\x08\xbaH\x05\x82\x01\x02\x10\x01R\x06ledger\x12\x12\n\x04open\x18\x03 \x01(\x08R\x04open\"~\n\x15\x43reateAccountResponse\x12>\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x07\x61\x63\x63ount\x12%\n\x0etransaction_id\x18\x02 \x01(\tR\rtransactionId\"8\n\x11GetAccountRequest\x12#\n\x06number\x18\x01 \x01(\tB\x0b\xbaH\x08r\x03\x98\x01\x07\xc8\x01\x01R\x06number\"T\n\x12GetAccountResponse\x12>\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x07\x61\x63\x63ount\"\x15\n\x13ListAccountsRequest\"X\n\x14ListAccountsResponse\x12@\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x08\x61\x63\x63ounts\";\n\x15SearchAccountsRequest\x12\"\n\x05label\x18\x01 \x01(\tB\x0c\xbaH\tr\x04\x10\x03\x18\x32\xc8\x01\x00R\x05label\"Z\n\x16SearchAccountsResponse\x12@\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.meshtrade.wallet.account.v1.AccountR\x08\x61\x63\x63ounts2\xca\x05\n\x0e\x41\x63\x63ountService\x12\xa3\x01\n\x06\x43reate\x12\x31.meshtrade.wallet.account.v1.CreateAccountRequest\x1a\x32.meshtrade.wallet.account.v1.CreateAccountResponse\"2\x92\xb5\x18*\n(meshtrade.wallet.account.v1.AccountAdmin\xa0\xb5\x18\x02\x12\xa7\x01\n\x03Get\x12..meshtrade.wallet.account.v1.GetAccountRequest\x1a/.meshtrade.wallet.account.v1.GetAccountResponse\"?\x8a\xb5\x18\x37\n5meshtrade.wallet.account.v1.AccountService.GetAccount\xa0\xb5\x18\x01\x12\xae\x01\n\x04List\x12\x30.meshtrade.wallet.account.v1.ListAccountsRequest\x1a\x31.meshtrade.wallet.account.v1.ListAccountsResponse\"A\x8a\xb5\x18\x39\n7meshtrade.wallet.account.v1.AccountService.ListAccounts\xa0\xb5\x18\x01\x12\xb6\x01\n\x06Search\x12\x32.meshtrade.wallet.account.v1.SearchAccountsRequest\x1a\x33.meshtrade.wallet.account.v1.SearchAccountsResponse\"C\x8a\xb5\x18;\n9meshtrade.wallet.account.v1.AccountService.SearchAccounts\xa0\xb5\x18\x01\x42\xa9\x04Z7github.com/meshtrade/api/go/wallet/account/v1;accountv1\x9a\xb5\x18\xeb\x03\n\xd6\x01\n)meshtrade.wallet.account.v1.AccountReader\x12\x35meshtrade.wallet.account.v1.AccountService.GetAccount\x12\x37meshtrade.wallet.account.v1.AccountService.ListAccounts\x12\x39meshtrade.wallet.account.v1.AccountService.SearchAccounts\n\x8f\x02\n(meshtrade.wallet.account.v1.AccountAdmin\x12\x38meshtrade.wallet.account.v1.AccountService.CreateAccount\x12\x35meshtrade.wallet.account.v1.AccountService.GetAccount\x12\x37meshtrade.wallet.account.v1.AccountService.ListAccounts\x12\x39meshtrade.wallet.account.v1.AccountService.SearchAccountsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.wallet.account.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/meshtrade/api/go/wallet/account/v1;accountv1\232\265\030\353\003\n\326\001\n)meshtrade.wallet.account.v1.AccountReader\0225meshtrade.wallet.account.v1.AccountService.GetAccount\0227meshtrade.wallet.account.v1.AccountService.ListAccounts\0229meshtrade.wallet.account.v1.AccountService.SearchAccounts\n\217\002\n(meshtrade.wallet.account.v1.AccountAdmin\0228meshtrade.wallet.account.v1.AccountService.CreateAccount\0225meshtrade.wallet.account.v1.AccountService.GetAccount\0227meshtrade.wallet.account.v1.AccountService.ListAccounts\0229meshtrade.wallet.account.v1.AccountService.SearchAccounts'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['label']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['label']._serialized_options = b'\272H\tr\004\020\003\0302\310\001\001'
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['ledger']._loaded_options = None
  _globals['_CREATEACCOUNTREQUEST'].fields_by_name['ledger']._serialized_options = b'\272H\005\202\001\002\020\001'
  _globals['_GETACCOUNTREQUEST'].fields_by_name['number']._loaded_options = None
  _globals['_GETACCOUNTREQUEST'].fields_by_name['number']._serialized_options = b'\272H\010r\003\230\001\007\310\001\001'
  _globals['_SEARCHACCOUNTSREQUEST'].fields_by_name['label']._loaded_options = None
  _globals['_SEARCHACCOUNTSREQUEST'].fields_by_name['label']._serialized_options = b'\272H\tr\004\020\003\0302\310\001\000'
  _globals['_ACCOUNTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['Create']._serialized_options = b'\222\265\030*\n(meshtrade.wallet.account.v1.AccountAdmin\240\265\030\002'
  _globals['_ACCOUNTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['Get']._serialized_options = b'\212\265\0307\n5meshtrade.wallet.account.v1.AccountService.GetAccount\240\265\030\001'
  _globals['_ACCOUNTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['List']._serialized_options = b'\212\265\0309\n7meshtrade.wallet.account.v1.AccountService.ListAccounts\240\265\030\001'
  _globals['_ACCOUNTSERVICE'].methods_by_name['Search']._loaded_options = None
  _globals['_ACCOUNTSERVICE'].methods_by_name['Search']._serialized_options = b'\212\265\030;\n9meshtrade.wallet.account.v1.AccountService.SearchAccounts\240\265\030\001'
  _globals['_CREATEACCOUNTREQUEST']._serialized_start=251
  _globals['_CREATEACCOUNTREQUEST']._serialized_end=390
  _globals['_CREATEACCOUNTRESPONSE']._serialized_start=392
  _globals['_CREATEACCOUNTRESPONSE']._serialized_end=518
  _globals['_GETACCOUNTREQUEST']._serialized_start=520
  _globals['_GETACCOUNTREQUEST']._serialized_end=576
  _globals['_GETACCOUNTRESPONSE']._serialized_start=578
  _globals['_GETACCOUNTRESPONSE']._serialized_end=662
  _globals['_LISTACCOUNTSREQUEST']._serialized_start=664
  _globals['_LISTACCOUNTSREQUEST']._serialized_end=685
  _globals['_LISTACCOUNTSRESPONSE']._serialized_start=687
  _globals['_LISTACCOUNTSRESPONSE']._serialized_end=775
  _globals['_SEARCHACCOUNTSREQUEST']._serialized_start=777
  _globals['_SEARCHACCOUNTSREQUEST']._serialized_end=836
  _globals['_SEARCHACCOUNTSRESPONSE']._serialized_start=838
  _globals['_SEARCHACCOUNTSRESPONSE']._serialized_end=928
  _globals['_ACCOUNTSERVICE']._serialized_start=931
  _globals['_ACCOUNTSERVICE']._serialized_end=1645
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/iam/role/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/iam/role/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.iam.role.v1 import role_pb2 as meshtrade_dot_iam_dot_role_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#meshtrade/iam/role/v1/service.proto\x12\x15meshtrade.iam.role.v1\x1a meshtrade/iam/role/v1/role.proto\"\x10\n\x0eGetRoleRequest\"B\n\x0fGetRoleResponse\x12/\n\x04role\x18\x01 \x01(\x0b\x32\x1b.meshtrade.iam.role.v1.RoleR\x04role2c\n\x0bRoleService\x12T\n\x03Get\x12%.meshtrade.iam.role.v1.GetRoleRequest\x1a&.meshtrade.iam.role.v1.GetRoleResponseB0Z.github.com/meshtrade/api/go/iam/role/v1;rolev1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.iam.role.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/meshtrade/api/go/iam/role/v1;rolev1'
  _globals['_GETROLEREQUEST']._serialized_start=96
  _globals['_GETROLEREQUEST']._serialized_end=112
  _globals['_GETROLERESPONSE']._serialized_start=114
  _globals['_GETROLERESPONSE']._serialized_end=180
  _globals['_ROLESERVICE']._serialized_start=182
  _globals['_ROLESERVICE']._serialized_end=281
# @@protoc_insertion_point(module_scope)



from meshtrade.trading.spot.v1 import spot_pb2 as _spot_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetSpotRequest(_message.Message):
    __slots__ = ("number",)
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    number: str
    def __init__(self, number: _Optional[str] = ...) -> None: ...

class GetSpotResponse(_message.Message):
    __slots__ = ("spot",)
    SPOT_FIELD_NUMBER: _ClassVar[int]
    spot: _spot_pb2.Spot
    def __init__(self, spot: _Optional[_Union[_spot_pb2.Spot, _Mapping]] = ...) -> None: ...



from meshtrade.iam.role.v1 import permission_pb2 as _permission_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Role(_message.Message):
    __slots__ = ("name", "permissions")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    name: str
    permissions: _containers.RepeatedCompositeFieldContainer[_permission_pb2.Permission]
    def __init__(self, name: _Optional[str] = ..., permissions: _Optional[_Iterable[_Union[_permission_pb2.Permission, _Mapping]]] = ...) -> None: ...



from meshtrade.trading.direct_order.v1 import direct_order_pb2 as _direct_order_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetDirectOrderRequest(_message.Message):
    __slots__ = ("number",)
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    number: str
    def __init__(self, number: _Optional[str] = ...) -> None: ...

class GetDirectOrderResponse(_message.Message):
    __slots__ = ("directorder",)
    DIRECTORDER_FIELD_NUMBER: _ClassVar[int]
    directorder: _direct_order_pb2.DirectOrder
    def __init__(self, directorder: _Optional[_Union[_direct_order_pb2.DirectOrder, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/option/v1/auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/option/v1/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emeshtrade/option/v1/auth.proto\x12\x13meshtrade.option.v1\x1a google/protobuf/descriptor.proto\"D\n\x0cStandardRole\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0bpermissions\x18\x02 \x03(\tR\x0bpermissions\"8\n\x14PermissionStringList\x12 \n\x0bpermissions\x18\x01 \x03(\tR\x0bpermissions\",\n\x14StandardRoleNameList\x12\x14\n\x05roles\x18\x01 \x03(\tR\x05roles\"K\n\x10StandardRoleList\x12\x37\n\x05roles\x18\x01 \x03(\x0b\x32!.meshtrade.option.v1.StandardRoleR\x05roles:~\n\x14required_permissions\x12\x1e.google.protobuf.MethodOptions\x18\xd1\x86\x03 \x01(\x0b\x32).meshtrade.option.v1.PermissionStringListR\x13requiredPermissions:r\n\x0erequired_roles\x12\x1e.google.protobuf.MethodOptions\x18\xd2\x86\x03 \x01(\x0b\x32).meshtrade.option.v1.StandardRoleNameListR\rrequiredRoles:l\n\x0estandard_roles\x12\x1c.google.protobuf.FileOptions\x18\xd3\x86\x03 \x01(\x0b\x32%.meshtrade.option.v1.StandardRoleListR\rstandardRolesB0Z.github.com/meshtrade/api/go/option/v1;optionv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.option.v1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/meshtrade/api/go/option/v1;optionv1'
  _globals['_STANDARDROLE']._serialized_start=89
  _globals['_STANDARDROLE']._serialized_end=157
  _globals['_PERMISSIONSTRINGLIST']._serialized_start=159
  _globals['_PERMISSIONSTRINGLIST']._serialized_end=215
  _globals['_STANDARDROLENAMELIST']._serialized_start=217
  _globals['_STANDARDROLENAMELIST']._serialized_end=261
  _globals['_STANDARDROLELIST']._serialized_start=263
  _globals['_STANDARDROLELIST']._serialized_end=338
# @@protoc_insertion_point(module_scope)



from meshtrade.iam.role.v1 import role_pb2 as _role_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetRoleRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetRoleResponse(_message.Message):
    __slots__ = ("role",)
    ROLE_FIELD_NUMBER: _ClassVar[int]
    role: _role_pb2.Role
    def __init__(self, role: _Optional[_Union[_role_pb2.Role, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/trading/spot/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/trading/spot/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from meshtrade.trading.spot.v1 import spot_pb2 as meshtrade_dot_trading_dot_spot_dot_v1_dot_spot__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'meshtrade/trading/spot/v1/service.proto\x12\x19meshtrade.trading.spot.v1\x1a$meshtrade/trading/spot/v1/spot.proto\"(\n\x0eGetSpotRequest\x12\x16\n\x06number\x18\x01 \x01(\tR\x06number\"F\n\x0fGetSpotResponse\x12\x33\n\x04spot\x18\x01 \x01(\x0b\x32\x1f.meshtrade.trading.spot.v1.SpotR\x04spot2k\n\x0bSpotService\x12\\\n\x03Get\x12).meshtrade.trading.spot.v1.GetSpotRequest\x1a*.meshtrade.trading.spot.v1.GetSpotResponseB4Z2github.com/meshtrade/api/go/trading/spot/v1;spotv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.trading.spot.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/meshtrade/api/go/trading/spot/v1;spotv1'
  _globals['_GETSPOTREQUEST']._serialized_start=108
  _globals['_GETSPOTREQUEST']._serialized_end=148
  _globals['_GETSPOTRESPONSE']._serialized_start=150
  _globals['_GETSPOTRESPONSE']._serialized_end=220
  _globals['_SPOTSERVICE']._serialized_start=222
  _globals['_SPOTSERVICE']._serialized_end=329
# @@protoc_insertion_point(module_scope)
